@@ -1,7 +1,7 @@
 /*
  * gti - a git launcher
  *
- * Copyright 2012 by Richard Wossal <richard@r-wos.org>
+ * Copyright 2012 Richard Wossal <richard@r-wos.org> and contributors.
  *
  * Permission to use, copy, modify, distribute, and sell this software
  * and its documentation for any purpose is hereby granted without fee,
@@ -16,7 +16,12 @@
 #    define WIN32
 #else
      /* fileno() */
+#if defined(__MVS__)
+     /* _POSIX_C_SOURCE has to be 1, 2 or 200112L on z/OS */
+#    define _POSIX_C_SOURCE 200112L
+#else
 #    define _POSIX_C_SOURCE 199506L
+#endif
      /* usleep() */
 #    define _DEFAULT_SOURCE
 #endif
@@ -74,6 +79,7 @@ void draw_std(int x);
 void draw_push(int x);
 void draw_pull(int x);
 void draw_tag(int x);
+void draw_commit(int x);
 draw_fn_t select_command(int argc, char **argv);
 
 FILE *TERM_FH;
@@ -128,6 +134,8 @@ draw_fn_t select_command(int argc, char **argv)
             return draw_pull;
         if (!strcmp(argv[i], "tag"))
             return draw_tag;
+        if (!strcmp(argv[i], "commit"))
+            return draw_commit;
         break;
     }
     return draw_std;
@@ -324,6 +332,42 @@ void draw_tag(int iteration)
     }
 }
 
+void draw_commit(int iteration)
+{
+    const int car_x = 4;
+    int car_y = 0;
+    int keyframe = ((iteration + 20) / 4) % 3;
+
+    /* *INDENT-OFF* */
+    move_to_top();
+    line_at(car_x, "     ,-------------, .     ");
+    line_at(car_x, "    /     [_o_]     \\|    ");
+    line_at(car_x, " []/_________________|[]   ");
+    line_at(car_x, "  /__/_____________\\__\\  ");
+    if (keyframe == 1)
+        line_at(car_x, "d|/$$\\=(_)=====(_)=/$$\\|b");
+    else if (keyframe == 2)
+        line_at(car_x, "d|/##\\=(_)=====(_)=/##\\|b");
+    else
+        line_at(car_x, "d|/``\\=(_)=====(_)=/``\\|b");
+    if (keyframe == 1)
+        line_at(car_x, " |\\$$/=============\\$$/| ");
+    else if (keyframe == 2)
+        line_at(car_x, " |\\##/=============\\##/| ");
+    else
+        line_at(car_x, " |\\__/=============\\__/| ");
+    line_at(car_x, " \\-----|__G_T_I__|-----/  ");
+    line_at(car_x, "  ||||             ||||");
+    /* *INDENT-ON* */
+    usleep(FRAME_TIME * 2);
+
+    /* clear it */
+    move_to_top();
+    for (car_y = 0; car_y < 8; car_y++) {
+        line_at(car_x, "                           ");
+    }
+}
+
 void clear_car(int x)
 {
     move_to_top();
